%
%                            SODA Ocean Model (T)

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';

% VARIABLES -- OPTIONAL
%Server = 'http://dods.gso.uri.edu:8080/dodsC/SODA';
Server = 'http://apdrc.soest.hawaii.edu/dods-bin/nph-dods/data/cmap-rain/rainfall.cmap.month.nc';

% VARIABLES -- REQUIRED
LonRange = [1.25-1.25 358.75+1.25];
LatRange = [-88.75-1.25 88.75+1.25];
TimeRange = [1978 2000];
DepthRange = [0 0];
DepthUnits = 'meters';
Resolution = 277.0;

% Force gridcat to ignore the axes popup window by forcing the axes order
axes_order = [3 2 0 1];

DataName = 'CMAP Precipitation';

SelectableVariables = str2mat('Precipitation');

DodsName = str2mat( 'cmap');

% note: DataNull is applied *before* scaling
DataNull = cell(size(DodsName,1)+4,1);
[DataNull(:)] = deal({nan}); 
[DataNull(5:length(DataNull))] = deal({-999});
DataScale = [NaN NaN; ...
             NaN NaN; ...
             NaN NaN; ...
             NaN NaN; ...
		 NaN NaN];

Acknowledge = ' ';

% COMMENTS
Comments = sprintf('%s\n', ...
'                 CPC Merged Analysis of Precipitation (CMAP)', ...
' ', ...
'    This data set consists of monthly averaged precipitation rates (mm/day). Values are', ...
'    obtained from 5 kinds of satellite estimates (GPI,OPI,SSM/I scattering, SSM/I emission', ...
'    and MSU). The data range is approximately 0 to 50mm/day.', ...
' ',...
'    References:', ...
' ', ...
'    Xie and Arkin, 1996: Analyses of Global Monthly Precipitation Using Gauge Observations,', ...
'         Satellite Estimates, and Numerical Model Predictions. J. Climate, 9, 840-858.', ...
' ', ...
'    Xie and Arkin, 1997: Global Precipitation: A 17-Year Monthly Analysis Based on Gauge', ...
'         Observations, Satellite Estimates and Numerical Model Outputs. BAMS, 78, (in press)', ... 
' ', ...
'   Original Source: Dr. Pingping Xie National Centers for Environmental Prediction, #800A', ...
'         National Oceanic and Atmospheric Administration Washington, DC 20233 ',...
'         Tel: (301)763-8167 Fax: (301)763-8125 E-mail: xping@sgi17.wwb.noaa.gov', ... 
' ' ,...
'   Originating Archive: ',...
' ', ...
'    Climate Diagnostics Center ',...
'    U.S. Dept. of Commerce ',...
'    NOAA/OAR/CDC, Code R/CDC1',... 
'    325 Broadway',... 
'    Boulder, CO 80305-3328',... 
' ',...
'   Contact person(s): ',...
' ',...
'    CDC Data Management ',...
'    Climate Diagnostics Center',... 
'    NOAA/OAR/CDC, Code R/CDC1 ',...
'    325 Broadway ',...
'    Boulder, CO 80305-3328',... 
'    cdcdata@cdc.noaa.gov ',...
' ',...
'  Data Server:',...
' ',...
'   IPRC SOEST',...
'   University of Hawaii',...
'   Honolulu, HI 96822',...
'   data@iprc.soest.hawaii.edu');

